using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

namespace Sample1
{
	/// <summary>
	/// Summary description for Form1.
	/// </summary>
	public class Form1 : System.Windows.Forms.Form
    {
        private XYChartNet.XYChartNETCtl xyChartNETCtl1;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public Form1()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			const double pi = 3.14159265358979;
			const int    myNumSamples = 73;
			const int    myXYSet = 4;

			double     val;
			double [,] DataArray = new double [myNumSamples, myXYSet];
			Font       myFont    = new Font("Arial", 16, FontStyle.Bold | FontStyle.Italic);

            xyChartNETCtl1.Dock = DockStyle.Fill;

			// Configure XY Chart NET control
			xyChartNETCtl1.Left=0;
			xyChartNETCtl1.Top=0;

			xyChartNETCtl1.NumProfiles = 2;
			xyChartNETCtl1.NumXScales = 1;
			xyChartNETCtl1.NumYScales = 1;

			xyChartNETCtl1.Title.Label = "Sample 1";
			xyChartNETCtl1.Title.Font = myFont;
			xyChartNETCtl1.Title.Color = Color.Blue;

			// Zoom window
			xyChartNETCtl1.ZoomWindowColor = Color.Yellow;

			// Gradient
			xyChartNETCtl1.Gradient.GradientOption = XYChartNet.XYChartNETCtl.GradientOptions.goCustom;
			xyChartNETCtl1.Gradient.StartColor = Color.LightSteelBlue;
			xyChartNETCtl1.Gradient.EndColor = Color.SkyBlue ;
			xyChartNETCtl1.Gradient.Orientation = XYChartNet.XYChartNETCtl.OrientationOptions.ooVertical;

			// Plot formatting
			xyChartNETCtl1.Plot.Transparent = true;
			xyChartNETCtl1.Plot.Border.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone;

			// Toolbar
			xyChartNETCtl1.Toolbar.Visible = true;
			xyChartNETCtl1.Toolbar.BackColor = Color.LightSteelBlue;
			xyChartNETCtl1.Toolbar.Dock = XYChartNet.XYChartNETCtl.PositionOptions.poTop;

			// Format Legend
			xyChartNETCtl1.Legend.Visible = true;
			xyChartNETCtl1.Legend.BorderVisible = false;
			xyChartNETCtl1.Legend.YScaleVisible = false;
			
			// Format Crosshairs
			xyChartNETCtl1.Crosshairs.YCoordInLegend = true;
			xyChartNETCtl1.Crosshairs.Color = Color.Yellow;
			xyChartNETCtl1.Crosshairs.Width = XYChartNet.XYChartNETCtl.WidthOptions.woTwoPoint ;
			xyChartNETCtl1.Crosshairs.CoordsBackcolor = Color.Yellow;
			xyChartNETCtl1.Crosshairs.HorizontalVisible = false;
			xyChartNETCtl1.Crosshairs.VerticalVisible = true;

			// X Axis Grid & Scale properties
			XYChartNet.XYChartNETCtl.C_XSCALEPROP xAxis;
			xAxis = xyChartNETCtl1.get_XAxis(0);
			xAxis.Grid.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			xAxis.Grid.LineColor = Color.Green;
			xAxis.Scale.Label = "Time (ms)";
			xAxis.Scale.LabelColor = Color.Black;
			xAxis.Scale.TicksColor = Color.Black;
			xAxis.Scale.ScaleMode = XYChartNet.XYChartNETCtl.ScaleModes.smAuto;

			// Y Axis Grid & Scale properties
			XYChartNet.XYChartNETCtl.C_YSCALEPROP yAxis;
			yAxis = xyChartNETCtl1.get_YAxis(0);
			yAxis.Grid.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			yAxis.Grid.LineColor = Color.Green;
			yAxis.Scale.Label = "Volts";
			yAxis.Scale.LabelColor = Color.Black;
			yAxis.Scale.TicksColor = Color.Black;
			yAxis.Scale.ScaleMode = XYChartNet.XYChartNETCtl.ScaleModes.smAuto;

			XYChartNet.XYChartNETCtl.C_Profile profile;

			// Format Profile 0
			profile = xyChartNETCtl1.get_Profile(0);
			profile.Label = "SINE";
			profile.YScale = 0;
			profile.NumSamples = myNumSamples;
			profile.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			profile.LineWidth = XYChartNet.XYChartNETCtl.WidthOptions.woThreePoint;
			profile.LineStyle = XYChartNet.XYChartNETCtl.StyleOptions.soSolid;
			profile.MarkerOption = XYChartNet.XYChartNETCtl.LineOptions.loNone;
			profile.LineColor = Color.Blue;
			profile.FillEnabled=true;
			profile.FillColor=Color.FromArgb(190,0,0,128);

			// Format Profile 1
			profile = xyChartNETCtl1.get_Profile(1);
			profile.Label = "COSINE";
			profile.YScale = 0;
			profile.NumSamples = myNumSamples;
			profile.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			profile.LineWidth = XYChartNet.XYChartNETCtl.WidthOptions.woThreePoint;
			profile.LineStyle = XYChartNet.XYChartNETCtl.StyleOptions.soSolid;
			profile.MarkerOption = XYChartNet.XYChartNETCtl.LineOptions.loNone;
			profile.LineColor = Color.Red;
			profile.FillEnabled=true;
			profile.FillColor=Color.FromArgb(190,255,0,0);

			// Generate Sine and Cosine profiles
			for (int row = 0; row < myNumSamples; row++)
			{
				// Profile 0
				val = 2 * pi * row / myNumSamples;
				DataArray[row, 0] = val;
				DataArray[row, 1] = Math.Sin(val);

				// Profile 1
				DataArray[row, 2] = val;
				DataArray[row, 3] = Math.Cos(val);
			}

			// Feed source array into XYChart
			xyChartNETCtl1.ChartData = DataArray;

			xyChartNETCtl1.Refresh();

		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(Form1));
            this.xyChartNETCtl1 = new XYChartNet.XYChartNETCtl();
            this.SuspendLayout();
            // 
            // xyChartNETCtl1
            // 
            this.xyChartNETCtl1.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("xyChartNETCtl1.BackgroundImage")));
            this.xyChartNETCtl1.Border.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone;
            this.xyChartNETCtl1.CausesValidation = false;
            this.xyChartNETCtl1.Location = new System.Drawing.Point(12, 12);
            this.xyChartNETCtl1.LogEvent.CTRLInstName = "XYChartNETCtl1";
            this.xyChartNETCtl1.LogEvent.FormName = "Form1";
            this.xyChartNETCtl1.Name = "xyChartNETCtl1";
            this.xyChartNETCtl1.Size = new System.Drawing.Size(511, 294);
            this.xyChartNETCtl1.TabIndex = 0;
            this.xyChartNETCtl1.Title.Font = new System.Drawing.Font("Arial", 8F);
            // 
            // Form1
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(831, 525);
            this.Controls.Add(this.xyChartNETCtl1);
            this.Name = "Form1";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
            this.Text = "Form1";
            this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new Form1());
		}
	}
}
