using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

namespace NullDataPoints
{
	/// <summary>
	/// Summary description for Form1.
	/// </summary>
	public class Form1 : System.Windows.Forms.Form
    {
        private XYChartNet.XYChartNETCtl xyChartNETCtl1;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public Form1()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			const int    myNumSamples = 30;
			const int    myXYSet = 2;

			double [,] ChartData = new double [myNumSamples, myXYSet];
			Font       myFont    = new Font("Arial", 16, FontStyle.Bold | FontStyle.Italic);
			double     NullDataValue = 1.79 * Math.Pow(10, 308);

            xyChartNETCtl1.Dock = DockStyle.Fill;

			// Configure XY Chart NET control
			xyChartNETCtl1.NumProfiles = 1;
			xyChartNETCtl1.NumXScales = 1;
			xyChartNETCtl1.NumYScales = 1;

			xyChartNETCtl1.BackColor = Color.DarkBlue;

			// Legend
			xyChartNETCtl1.Legend.Visible = true;
			xyChartNETCtl1.Legend.BorderVisible = false;
			xyChartNETCtl1.Legend.YScaleVisible = false;
			
			xyChartNETCtl1.Title.Label = "Null Data Points";
			xyChartNETCtl1.Title.Font = myFont;
			xyChartNETCtl1.Title.Color = Color.White;

			// Toolbar
			xyChartNETCtl1.Toolbar.Visible = true;
			xyChartNETCtl1.Toolbar.BackColor = Color.Lavender;

			// Crosshairs
			xyChartNETCtl1.Crosshairs.YCoordInLegend = true;
			xyChartNETCtl1.Crosshairs.Color = Color.Blue;
			xyChartNETCtl1.Crosshairs.Width = XYChartNet.XYChartNETCtl.WidthOptions.woTwoPoint;
			xyChartNETCtl1.Crosshairs.CoordsBackcolor = Color.Green;
			xyChartNETCtl1.Crosshairs.HorizontalVisible = false;
			xyChartNETCtl1.Crosshairs.VerticalVisible = true;

			// Plot formatting
			xyChartNETCtl1.Plot.BackColor = Color.Lavender;
			xyChartNETCtl1.Plot.Border.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone;

			// X Axis Grid & Scale properties
			XYChartNet.XYChartNETCtl.C_XSCALEPROP xAxis;
			xAxis = xyChartNETCtl1.get_XAxis(0);
			xAxis.Grid.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			xAxis.Grid.LineColor = Color.Green;
			xAxis.Scale.Label = "";
			xAxis.Scale.LabelColor = Color.White;
			xAxis.Scale.TicksColor = Color.White;
			xAxis.Scale.ScaleMode = XYChartNet.XYChartNETCtl.ScaleModes.smAuto;

			// Y Axis Grid & Scale properties
			XYChartNet.XYChartNETCtl.C_YSCALEPROP yAxis;
			yAxis = xyChartNETCtl1.get_YAxis(0);
			yAxis.Grid.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			yAxis.Grid.LineColor = Color.Green;
			yAxis.Scale.Label = "";
			yAxis.Scale.LabelColor = Color.White;
			yAxis.Scale.TicksColor = Color.White;
			yAxis.Scale.ScaleMode = XYChartNet.XYChartNETCtl.ScaleModes.smAuto;

			// Profile 0
			XYChartNet.XYChartNETCtl.C_Profile profile;
			profile = xyChartNETCtl1.get_Profile(0);
			profile.XScale = 0;
			profile.YScale = 0;
			profile.Label = "Profile 0";
			profile.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			profile.LineWidth = XYChartNet.XYChartNETCtl.WidthOptions.woOnePoint;
			profile.LineStyle = XYChartNet.XYChartNETCtl.StyleOptions.soSolid;
			profile.LineColor = Color.Maroon;
			profile.MarkerOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			profile.MarkerStyle = XYChartNet.XYChartNETCtl.MarkerStyleOptions.msDiamond;
			profile.MarkerSize = 4;
			profile.MarkerFillColor = Color.Maroon;
			profile.MarkerBorderColor = Color.Maroon;
			profile.NumSamples = myNumSamples;

			// Create random chart data, then feed into XYChartNET
			Random rnd = new Random();
			for (int i = 0; i < myNumSamples; i++)
			{
				ChartData[i, 0] = i * 1;
				if (i == 0)
					ChartData[i, 1] = 0;			// Force first y value to zero
				else
				{
					if (rnd.NextDouble() <= 0.2)			// Set random null values 20% of time
						ChartData[i, 1] = NullDataValue;
					else
						ChartData[i, 1] = 100 * rnd.NextDouble();
				}
			}
			xyChartNETCtl1.ChartData = ChartData;

			xyChartNETCtl1.Refresh();
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(Form1));
            this.xyChartNETCtl1 = new XYChartNet.XYChartNETCtl();
            this.SuspendLayout();
            // 
            // xyChartNETCtl1
            // 
            this.xyChartNETCtl1.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("xyChartNETCtl1.BackgroundImage")));
            this.xyChartNETCtl1.Border.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone;
            this.xyChartNETCtl1.CausesValidation = false;
            this.xyChartNETCtl1.Location = new System.Drawing.Point(37, 37);
            this.xyChartNETCtl1.LogEvent.CTRLInstName = "XYChartNETCtl1";
            this.xyChartNETCtl1.LogEvent.FormName = "Form1";
            this.xyChartNETCtl1.Name = "xyChartNETCtl1";
            this.xyChartNETCtl1.Size = new System.Drawing.Size(432, 310);
            this.xyChartNETCtl1.TabIndex = 0;
            this.xyChartNETCtl1.Title.Font = new System.Drawing.Font("Arial", 8F);
            // 
            // Form1
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(788, 515);
            this.Controls.Add(this.xyChartNETCtl1);
            this.Name = "Form1";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
            this.Text = "Form1";
            this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new Form1());
		}
	}
}
