using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

namespace ScaleUnits
{
	/// <summary>
	/// Summary description for Form1.
	/// </summary>
	public class Form1 : System.Windows.Forms.Form
	{
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.ContextMenu mnuX1UnitsList;
		private System.Windows.Forms.MenuItem mnuX1Units_sec;
		private System.Windows.Forms.MenuItem mnuX1Units_min;
		private System.Windows.Forms.ContextMenu mnuY1UnitsList;
		private System.Windows.Forms.MenuItem mnuY1Units_inch;
        private System.Windows.Forms.MenuItem mnuY1Units_cm;
        private XYChartNet.XYChartNETCtl xyChartNETCtl1;

		// NOTE:  Set the XYChartNET control's Anchor property to 'Top, Bottom, Left, Right'.

		private int iScaleIndex;

		public Form1()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			const int myNumSamples = 10;
			const int myXYSet = 4;

			Font       myTitleFont = new Font("Arial", 16, FontStyle.Bold | FontStyle.Italic);
			Font       my14Font = new Font("Arial", 14, FontStyle.Bold);
			Font       my10Font = new Font("Arial", 10, FontStyle.Bold);
			double [,] ChartData = new double [myNumSamples, myXYSet];

            xyChartNETCtl1.Dock = DockStyle.Fill;

			XYChartNet.XYChartNETCtl.C_XSCALEPROP xAxis;
			XYChartNet.XYChartNETCtl.C_YSCALEPROP yAxis;
			XYChartNet.XYChartNETCtl.C_Profile  profile;

			// Configure XY Chart NET control
			xyChartNETCtl1.NumProfiles = 2;
			xyChartNETCtl1.NumXScales = 2;
			xyChartNETCtl1.NumYScales = 2;

			// Init Chart Data for Profile 0 (x-values are in seconds; y-values are in inches)
			ChartData[0, 0] = 0;
			ChartData[0, 1] = 0;
			ChartData[1, 0] = 10;
			ChartData[1, 1] = 1;
			ChartData[2, 0] = 20;
			ChartData[2, 1] = 2;
			ChartData[3, 0] = 30;
			ChartData[3, 1] = 4;
			ChartData[4, 0] = 40;
			ChartData[4, 1] = 8;
			ChartData[5, 0] = 50;
			ChartData[5, 1] = 16;
			ChartData[6, 0] = 60;
			ChartData[6, 1] = 32;
			ChartData[7, 0] = 70;
			ChartData[7, 1] = 64;
			ChartData[8, 0] = 80;
			ChartData[8, 1] = 128;
			ChartData[9, 0] = 90;
			ChartData[9, 1] = 256;

			// Init Chart Data for Profile 1 (x-values are in seconds; y-values are in inches)
			ChartData[0, 2] = 0;
			ChartData[0, 3] = 0;
			ChartData[1, 2] = 1;
			ChartData[1, 3] = 10;
			ChartData[2, 2] = 2;
			ChartData[2, 3] = 20;
			ChartData[3, 2] = 3;
			ChartData[3, 3] = 30;
			ChartData[4, 2] = 4;
			ChartData[4, 3] = 40;
			ChartData[5, 2] = 5;
			ChartData[5, 3] = 50;
			ChartData[6, 2] = 6;
			ChartData[6, 3] = 60;
			ChartData[7, 2] = 7;
			ChartData[7, 3] = 70;
			ChartData[8, 2] = 8;
			ChartData[8, 3] = 80;
			ChartData[9, 2] = 9;
			ChartData[9, 3] = 90;

			// Legend
			xyChartNETCtl1.Legend.Visible = true;
			xyChartNETCtl1.Legend.Position = XYChartNet.XYChartNETCtl.RLPositionOptions.rlRight;
			xyChartNETCtl1.Legend.BorderVisible = false;
			xyChartNETCtl1.Legend.YScaleVisible = false;
    			
			// Crosshairs
			xyChartNETCtl1.Crosshairs.YCoordInLegend = true;
			xyChartNETCtl1.Crosshairs.Color = Color.Yellow;
			xyChartNETCtl1.Crosshairs.Width = XYChartNet.XYChartNETCtl.WidthOptions.woTwoPoint;
			xyChartNETCtl1.Crosshairs.CoordsBackcolor = Color.Yellow;
			xyChartNETCtl1.Crosshairs.HorizontalVisible = false;
			xyChartNETCtl1.Crosshairs.VerticalVisible = true;

			// Toolbar and Title
			xyChartNETCtl1.Title.Label = "Scale Factors (right-click on any scale)";
			xyChartNETCtl1.Title.Font = myTitleFont;
			xyChartNETCtl1.Title.Color = Color.Blue;
			xyChartNETCtl1.Toolbar.BackColor = Color.Lavender;
			xyChartNETCtl1.Toolbar.Dock = XYChartNet.XYChartNETCtl.PositionOptions.poTop;

			// Chart and plot formatting
			xyChartNETCtl1.BackColor = Color.Lavender;
			xyChartNETCtl1.Plot.BackColor = Color.Lavender;
			xyChartNETCtl1.Plot.Border.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			xyChartNETCtl1.Plot.Border.LineWidth = XYChartNet.XYChartNETCtl.WidthOptions.woOnePoint;
			xyChartNETCtl1.Plot.Border.LineColor = Color.Green;

			// X Axis 0 Grid & Scale properties
			xAxis = xyChartNETCtl1.get_XAxis(0);
			xAxis.Grid.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			xAxis.Grid.LineColor = Color.Maroon;
			xAxis.Scale.Label = "seconds";
			xAxis.Scale.LabelColor = Color.Maroon;
			xAxis.Scale.TicksColor = Color.Maroon;
			xAxis.Scale.TicksFont = my14Font;
			xAxis.Scale.Position = XYChartNet.XYChartNETCtl.ScalePositionOptions.spLeftOrBottom;
			xAxis.Scale.Visible = true;

			// X Axis 1 Grid & Scale properties
			xAxis = xyChartNETCtl1.get_XAxis(1);
			xAxis.Grid.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			xAxis.Grid.LineColor = Color.DarkBlue;
			xAxis.Scale.Label = "seconds";
			xAxis.Scale.LabelColor = Color.DarkBlue;
			xAxis.Scale.TicksColor = Color.DarkBlue;
			xAxis.Scale.TicksFont = my10Font;
			xAxis.Scale.Position = XYChartNet.XYChartNETCtl.ScalePositionOptions.spRightOrTop;
			xAxis.Scale.Visible = true;

			// Y Axis 0 Grid & Scale properties
			yAxis = xyChartNETCtl1.get_YAxis(0);
			yAxis.Grid.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			yAxis.Grid.LineColor = Color.Maroon;
			yAxis.Scale.LabelVertical = "inches";
			yAxis.Scale.LabelVerticalColor = Color.Maroon;
			yAxis.Scale.TicksColor = Color.Maroon;
			yAxis.Scale.TicksFont = my14Font;
			yAxis.Scale.Position = XYChartNet.XYChartNETCtl.ScalePositionOptions.spLeftOrBottom;
			yAxis.Scale.Visible = true;

			// Y Axis 1 Grid & Scale properties
			yAxis = xyChartNETCtl1.get_YAxis(1);
			yAxis.Grid.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			yAxis.Grid.LineColor = Color.DarkBlue;
			yAxis.Scale.LabelVertical = "inches";
			yAxis.Scale.LabelVerticalColor = Color.DarkBlue;
			yAxis.Scale.TicksColor = Color.DarkBlue;
			yAxis.Scale.TicksFont = my10Font;
			yAxis.Scale.Position = XYChartNet.XYChartNETCtl.ScalePositionOptions.spRightOrTop;
			yAxis.Scale.Visible = true;

			// Profile 0
			profile = xyChartNETCtl1.get_Profile(0);
			profile.NumSamples = myNumSamples;
			profile.XScale = 0;
			profile.YScale = 0;
			profile.Label = "Profile 0";
			profile.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			profile.LineWidth = XYChartNet.XYChartNETCtl.WidthOptions.woThreePoint;
			profile.LineStyle = XYChartNet.XYChartNETCtl.StyleOptions.soSolid;
			profile.LineColor = Color.Maroon;
			profile.MarkerOption = XYChartNet.XYChartNETCtl.LineOptions.loNone;

			// Profile 1
			profile = xyChartNETCtl1.get_Profile(1);
			profile.NumSamples = myNumSamples;
			profile.XScale = 1;
			profile.YScale = 1;
			profile.Label = "Profile 1";
			profile.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			profile.LineWidth = XYChartNet.XYChartNETCtl.WidthOptions.woThreePoint;
			profile.LineStyle = XYChartNet.XYChartNETCtl.StyleOptions.soSolid;
			profile.LineColor = Color.DarkBlue;
			profile.MarkerOption = XYChartNet.XYChartNETCtl.LineOptions.loNone;

			// Assign the data and update the chart
			xyChartNETCtl1.ChartData = ChartData;

			xyChartNETCtl1.Left = 0;
			xyChartNETCtl1.Top=0;
			xyChartNETCtl1.Refresh();
    
		}

		// X-Scale MouseDown Event
		private void XYChartNETCtl1_XScaleMouseDown(System.Windows.Forms.MouseButtons Button, int Index, int xPos, int yPos)
		{
			XYChartNet.XYChartNETCtl.C_XSCALEPROP xAxis;

			if (Button == MouseButtons.Right)
			{
				iScaleIndex = Index;
				xAxis = xyChartNETCtl1.get_XAxis(iScaleIndex);
				if (xAxis.Scale.ScaleFactor == 1)
				{
					mnuX1Units_sec.Checked = true;
					mnuX1Units_min.Checked = false;
				}
				else
				{
					mnuX1Units_sec.Checked = false;
					mnuX1Units_min.Checked = true;
				}
				mnuX1UnitsList.Show(xyChartNETCtl1, new Point(xPos, yPos));
			}
		}

		private void XYChartNETCtl1_PlotDoubleClick(int Index, int xPos, int yPos)
		{
			xyChartNETCtl1.SetZoomOutAll();
		}


		// Y-Scale MouseDown Event
		private void XYChartNETCtl1_YScaleMouseDown(System.Windows.Forms.MouseButtons Button, int Index, int xPos, int yPos)
		{
            XYChartNet.XYChartNETCtl.C_YSCALEPROP yAxis;

			if (Button == MouseButtons.Right)
			{
				iScaleIndex = Index;
				yAxis = xyChartNETCtl1.get_YAxis(iScaleIndex);
				if (yAxis.Scale.ScaleFactor == 1)
				{
					mnuY1Units_inch.Checked = true;
					mnuY1Units_cm.Checked = false;
				}
				else
				{
					mnuY1Units_inch.Checked = false;
					mnuY1Units_cm.Checked = true;
				}
				mnuY1UnitsList.Show(xyChartNETCtl1, new Point(xPos, yPos));
			}
		}

 
		// Popup menu events
		private void mnuX1Units_sec_Click(object sender, System.EventArgs e)
		{
            XYChartNet.XYChartNETCtl.C_XSCALEPROP xAxis;

			xAxis = xyChartNETCtl1.get_XAxis(iScaleIndex);
			xAxis.Scale.ScaleFactor = 1;		// Since the base unit for the x-values is in seconds
			xAxis.Scale.Label = "seconds";

			// In case we are in the zoomed-in state, use Redraw in order to maintain the current min and max values
			xyChartNETCtl1.Redraw();
		}

		private void mnuX1Units_min_Click(object sender, System.EventArgs e)
		{
            XYChartNet.XYChartNETCtl.C_XSCALEPROP xAxis;

			xAxis = xyChartNETCtl1.get_XAxis(iScaleIndex);
			xAxis.Scale.ScaleFactor = (double) 1 / 60;		// Since the base unit for the x-values is in seconds
			xAxis.Scale.Label = "minutes";

			// In case we are in the zoomed-in state, use Redraw in order to maintain the current min and max values
			xyChartNETCtl1.Redraw();
		}

		private void mnuY1Units_inch_Click(object sender, System.EventArgs e)
		{
            XYChartNet.XYChartNETCtl.C_YSCALEPROP yAxis;

			yAxis = xyChartNETCtl1.get_YAxis(iScaleIndex);
			yAxis.Scale.ScaleFactor = 1;		// Since the base unit for the y-values is in inches
			yAxis.Scale.LabelVertical = "inches";

			// In case we are in the zoomed-in state, use Redraw in order to maintain the current min and max values
			xyChartNETCtl1.Redraw();
		}

		private void mnuY1Units_cm_Click(object sender, System.EventArgs e)
		{
            XYChartNet.XYChartNETCtl.C_YSCALEPROP yAxis;

			yAxis = xyChartNETCtl1.get_YAxis(iScaleIndex);
			yAxis.Scale.ScaleFactor = 2.54;	
			yAxis.Scale.LabelVertical = "cm";

			// In case we are in the zoomed-in state, use Redraw in order to maintain the current min and max values
			xyChartNETCtl1.Redraw();
		}

		private void XYChartNETCtl1_Load(object sender, EventArgs e)
		{
			// Nothing
		}
	
		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(Form1));
            this.mnuX1UnitsList = new System.Windows.Forms.ContextMenu();
            this.mnuX1Units_sec = new System.Windows.Forms.MenuItem();
            this.mnuX1Units_min = new System.Windows.Forms.MenuItem();
            this.mnuY1UnitsList = new System.Windows.Forms.ContextMenu();
            this.mnuY1Units_inch = new System.Windows.Forms.MenuItem();
            this.mnuY1Units_cm = new System.Windows.Forms.MenuItem();
            this.xyChartNETCtl1 = new XYChartNet.XYChartNETCtl();
            this.SuspendLayout();
            // 
            // mnuX1UnitsList
            // 
            this.mnuX1UnitsList.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
            this.mnuX1Units_sec,
            this.mnuX1Units_min});
            // 
            // mnuX1Units_sec
            // 
            this.mnuX1Units_sec.Checked = true;
            this.mnuX1Units_sec.Index = 0;
            this.mnuX1Units_sec.Text = "s";
            this.mnuX1Units_sec.Click += new System.EventHandler(this.mnuX1Units_sec_Click);
            // 
            // mnuX1Units_min
            // 
            this.mnuX1Units_min.Index = 1;
            this.mnuX1Units_min.Text = "min";
            this.mnuX1Units_min.Click += new System.EventHandler(this.mnuX1Units_min_Click);
            // 
            // mnuY1UnitsList
            // 
            this.mnuY1UnitsList.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
            this.mnuY1Units_inch,
            this.mnuY1Units_cm});
            // 
            // mnuY1Units_inch
            // 
            this.mnuY1Units_inch.Checked = true;
            this.mnuY1Units_inch.Index = 0;
            this.mnuY1Units_inch.Text = "inches";
            this.mnuY1Units_inch.Click += new System.EventHandler(this.mnuY1Units_inch_Click);
            // 
            // mnuY1Units_cm
            // 
            this.mnuY1Units_cm.Index = 1;
            this.mnuY1Units_cm.Text = "cm";
            this.mnuY1Units_cm.Click += new System.EventHandler(this.mnuY1Units_cm_Click);
            // 
            // xyChartNETCtl1
            // 
            this.xyChartNETCtl1.BackColor = System.Drawing.SystemColors.Control;
            this.xyChartNETCtl1.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("xyChartNETCtl1.BackgroundImage")));
            this.xyChartNETCtl1.Border.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone;
            this.xyChartNETCtl1.CausesValidation = false;
            this.xyChartNETCtl1.CustomToolbar.BackColor = System.Drawing.SystemColors.Control;
            this.xyChartNETCtl1.Location = new System.Drawing.Point(49, 31);
            this.xyChartNETCtl1.LogEvent.CTRLInstName = "XYChartNETCtl1";
            this.xyChartNETCtl1.LogEvent.FormName = "Form1";
            this.xyChartNETCtl1.Name = "xyChartNETCtl1";
            this.xyChartNETCtl1.Size = new System.Drawing.Size(484, 376);
            this.xyChartNETCtl1.TabIndex = 0;
            this.xyChartNETCtl1.Title.Font = new System.Drawing.Font("Arial", 8F);
            this.xyChartNETCtl1.Toolbar.BackColor = System.Drawing.Color.FromArgb(((int)(((byte)(211)))), ((int)(((byte)(222)))), ((int)(((byte)(237)))));
            this.xyChartNETCtl1.PlotDoubleClick += new XYChartNet.XYChartNETCtl.PlotDoubleClickEventHandler(this.XYChartNETCtl1_PlotDoubleClick);
            this.xyChartNETCtl1.XScaleMouseDown += new XYChartNet.XYChartNETCtl.XScaleMouseDownEventHandler(this.XYChartNETCtl1_XScaleMouseDown);
            this.xyChartNETCtl1.YScaleMouseDown += new XYChartNet.XYChartNETCtl.YScaleMouseDownEventHandler(this.XYChartNETCtl1_YScaleMouseDown);
            // 
            // Form1
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(806, 526);
            this.Controls.Add(this.xyChartNETCtl1);
            this.Name = "Form1";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
            this.Text = "Form1";
            this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new Form1());
		}
	}
}
