Public Class Form1

    Private ChartData(,) As Double

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

        Dim myFont As New Font("Arial", 16, FontStyle.Italic Or FontStyle.Bold)
        Dim i As Integer

        Const NullDataValue As Double = 1.79 * 10 ^ 308

        ' Configure XY Chart NET control
        With XyChartNETCtl1
            .SendToBack()
            .Dock = DockStyle.Fill

            .NumProfiles = 1
            .NumXScales = 1
            .NumYScales = 1

            .Title.Label = "Data Points with Labels"
            .Title.Font = myFont
            .Title.Color = Color.White

            ' Toolbar
            With .Toolbar
                .Visible = True
                .BackColor = Me.BackColor ' Color.Lavender
            End With

            ' Format Legend
            With .Legend
                .Visible = True
                .BorderVisible = False
                .YScaleVisible = False
            End With

            ' Chart & plot formatting
            .BackColor = Color.SteelBlue
            With .Gradient
                .GradientOption = XYChartNet.XYChartNETCtl.GradientOptions.goCustom
                .Orientation = XYChartNet.XYChartNETCtl.OrientationOptions.ooVertical
                .StartColor = Color.SteelBlue
                .EndColor = Color.Blue
            End With

            .Plot.BackColor = Color.Lavender
            .Plot.Border.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone

            ' X Axis
            With .XAxis(0)
                With .Grid
                    .LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom
                    .LineColor = Color.Green
                End With
                With .Scale
                    .Visible = True
                    .Label = ""
                    .LabelColor = Color.White
                    .TicksColor = Color.White
                    .ScaleMode = XYChartNet.XYChartNETCtl.ScaleModes.smAuto
                End With
            End With

            ' Y Axis
            With .YAxis(0)
                With .Grid
                    .LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom
                    .LineColor = Color.Green
                End With
                With .Scale
                    .Visible = True
                    .Label = ""
                    .LabelColor = Color.White
                    .TicksColor = Color.White
                    .ScaleMode = XYChartNet.XYChartNETCtl.ScaleModes.smAuto
                End With
            End With

            ' Format Profile 0
            With .Profile(0)
                .XScale = 0
                .YScale = 0
                .Label = "Profile 0"
                .LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom
                .LineWidth = XYChartNet.XYChartNETCtl.WidthOptions.woOnePoint
                .LineStyle = XYChartNet.XYChartNETCtl.StyleOptions.soSolid
                .LineColor = Color.Maroon
                .MarkerOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom
                .MarkerStyle = XYChartNet.XYChartNETCtl.MarkerStyleOptions.msDiamond
                .MarkerSize = 4
                .MarkerFillColor = Color.Maroon
                .MarkerBorderColor = Color.Maroon
                .NumSamples = 10
            End With

            ' Create random chart data, then feed into XYChartNET
            ReDim ChartData(.Profile(0).NumSamples - 1, 2 * .NumProfiles - 1)
            For i = 0 To .Profile(0).NumSamples - 1
                ChartData(i, 0) = i * 1
                If i = 0 Then
                    ChartData(i, 1) = 0 ' Force first y value to zero
                Else
                    If Rnd() <= 0.2 Then ' Set random null values 20% of time
                        ChartData(i, 1) = NullDataValue
                    Else
                        ChartData(i, 1) = 100 * Rnd()
                    End If
                End If
            Next i
            .ChartData = ChartData

            ' Format Crosshairs
            With .Crosshairs
                .YCoordInLegend = True
                .Color = Color.Blue
                .Width = XYChartNet.XYChartNETCtl.WidthOptions.woTwoPoint
                .CoordsBackcolor = Color.Green
                .HorizontalVisible = False
                .VerticalVisible = True
            End With

            .Refresh()

        End With

    End Sub

    Private Sub XyChartNETCtl1_Paint(ByVal sender As Object, ByVal e As System.Windows.Forms.PaintEventArgs) Handles XyChartNETCtl1.Paint
        Dim myFont As New Font("Arial", 8, FontStyle.Bold)
        Dim strLabel As String

        Dim i As Integer
        Dim XValue As Double
        Dim YValue As Double
        Dim XPos As Single
        Dim YPos As Single

        Const X_OFFSET As Single = 4
        Const Y_OFFSET As Single = 4

        Label1.Font = myFont

        With XyChartNETCtl1
            For i = 0 To .Profile(0).NumSamples - 1
                XValue = ChartData(i, 0)
                YValue = ChartData(i, 1)

                ' Check DataPoint is within the plot area (in case user has zoomed in)
                If XValue >= .MinXValue(0) And XValue <= .MaxXValue(0) And _
                   YValue >= .MinYValue(0) And YValue <= .MaxYValue(0) Then

                    strLabel = "[" + FormatNumber(ChartData(i, 0), 1) + ", " + FormatNumber(ChartData(i, 1), 1) + "]"
                    Label1.Text = strLabel ' Use to get width and height of text string

                    XPos = .YStack(0).Left + .YStack(0).Width * (XValue - .MinXValue(0)) / (.MaxXValue(0) - .MinXValue(0))
                    YPos = .YStack(0).Top + .YStack(0).Height * (.MaxYValue(0) - YValue) / (.MaxYValue(0) - .MinYValue(0))

                    ' Make sure label does not cross outside the plot area
                    If (XPos + Label1.Width + X_OFFSET) > (.YStack(0).Left + .YStack(0).Width - 1) Then
                        ' Position to the left of the datapoint
                        XPos = XPos - Label1.Width - X_OFFSET
                    Else
                        ' Position to the right of the datapoint
                        XPos = XPos + X_OFFSET
                    End If

                    ' Make sure label does not cross outside the plot area
                    If (YPos + Label1.Height + Y_OFFSET) > (.YStack(0).Top + .YStack(0).Height - 1) Then
                        ' Position above the datapoint
                        YPos = YPos - Label1.Height - Y_OFFSET
                    Else
                        ' Position below the datapoint
                        YPos = YPos + Y_OFFSET
                    End If

                    ' Display Label
                    e.Graphics.DrawString(strLabel, myFont, Brushes.Blue, XPos, YPos)

                End If
            Next i
        End With
    End Sub

    Private Sub XyChartNETCtl1_PlotDoubleClick(ByVal Index As Integer, ByVal xPos As Integer, ByVal yPos As Integer) Handles XyChartNETCtl1.PlotDoubleClick
        XyChartNETCtl1.SetZoomOutAll()
    End Sub

End Class
